.. This file provides the instructions for how to display the API documentation generated using sphinx autodoc
   extension. Use it to declare Python documentation sub-directories via appropriate modules (autodoc, etc.).

Video System
============

.. automodule:: ataraxis_video_system.video_system
   :members:
   :show-inheritance:

Camera
======

.. automodule:: ataraxis_video_system.camera
   :members:
   :show-inheritance:

Saver
=====

.. automodule:: ataraxis_video_system.saver
   :members:
   :show-inheritance:

Command Line Interfaces (CLIs)
==============================

.. click:: ataraxis_video_system.cli:axvs_cli
   :prog: axvs
   :nested: full
